@@ -23,4 +23,9 @@ class Logger(object):
         """
         marker="✅" if ok else "❌"
         print(f"{msg}:{marker}")
-        return ok
\ No newline at end of file
+        return ok
+    
+    @classmethod
+    def check_and_log_equal(self,nameA,valueA,nameB,valueB):
+        msg=f"{nameA} {valueA}= {nameB} {valueB}?"
+        return self.check_and_log(msg, valueA==valueB)
\ No newline at end of file
